# Python Space Mission Analysis and Design

## Overview

This package is a public astrodynamics analysis and simulation sandbox not intended for commercial use.  Further details
on functionality can be found on the [documentation page](https://www.openspace-docs.com).  For an interactive demonstration of possible uses, try the [openspace](https://www.openspace-app.com/) application.

## Contributing

When making contributions to the openspace code repository, please follow these standards as closely as possible:

- Use [black](https://pypi.org/project/black/) to format all python code
- Use [sphinx](https://www.sphinx-doc.org/en/master/) docstrings for code documentation
- Use [PEP484](https://peps.python.org/pep-0484/) type hinting
- Open issues when making changes that are intended to be merged to the main branch

## License

This packages is not intended for commercial use; however, it is not strictly prohibited.  Instead, you may use this
package for commercial use assuming you make any source code publicly available when using this package.
